DocError

Enum DocError 

#[non_exhaustive]
pub enum DocError {
Show 18 variants InvalidTypeId(String), DuplicateId(String), UnknownEntity(EntityId), UnknownConstraint(ConstraintId), UnknownLayer(LayerId), UnknownGroup(GroupId), BrokenReference { from: String, target: String, }, MissingAnchor { entity: EntityId, anchor: String, }, MissingParam { entity: EntityId, param: String, }, GroupCycle(GroupId), MultipleParents(String), BadOrder(String), InvalidGeometry { entity: EntityId, reason: String, }, InvalidValue(String), LimitExceeded(String), FutureSchema { found: u32, supported: u32, }, UnsupportedSchema(u32), Malformed(String),
}
Document-level errors (invariant violations, invalid edits, limits).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidTypeId(String)

Malformed type identifier.



DuplicateId(String)

The same ID appears twice.



UnknownEntity(EntityId)

An entity does not exist.



UnknownConstraint(ConstraintId)

A constraint does not exist.



UnknownLayer(LayerId)

A layer does not exist.



UnknownGroup(GroupId)

A group does not exist.



BrokenReference

A reference points to a missing target.

Fields

from: String

Referencing object.

target: String

Missing target.



MissingAnchor

An anchor name is not provided by the referenced entity.

Fields

entity: EntityId

Entity.

anchor: String

Anchor name.



MissingParam

A parameter name is not provided by the referenced entity.

Fields

entity: EntityId

Entity.

param: String

Parameter name.



GroupCycle(GroupId)

Group nesting forms a cycle.



MultipleParents(String)

An entity or group belongs to more than one group.



BadOrder(String)

The entity order list is not a permutation of the entities.



InvalidGeometry

Geometry is invalid.

Fields

entity: EntityId

Entity.

reason: String

Reason.



InvalidValue(String)

A value is invalid.



LimitExceeded(String)

A configured limit was exceeded.



FutureSchema

The document schema is newer than this library supports.

Fields

found: u32

Schema found in the file.

supported: u32

Newest supported schema.



UnsupportedSchema(u32)

The document schema is older than any supported migration.



Malformed(String)

JSON (de)serialization error.